@@ -2,9 +2,8 @@
 #include <QtGui>
 #include <QWebFrame>
 
-#if defined(Q_WS_MAEMO_5)
-#   include <QAbstractKineticScroller>
-#elif defined(Q_OS_SYMBIAN)
+#if defined(Q_OS_SYMBIAN)
+#   include "mediakeysobserver.h"
 #   include "flickcharm.h"
 #endif
 
@@ -17,12 +16,13 @@
 #include "progressdialog.h"
 #include "platform.h"
 
-BookView::BookView(QWidget *parent):
-    QWebView(parent), contentIndex(-1), mBook(0),
-    restorePositionAfterLoad(false), positionAfterLoad(0), loaded(false),
-    contentsHeight(0)
+BookView::BookView(QWidget *parent): QWebView(parent), contentIndex(-1),
+    mBook(0), restorePositionAfterLoad(false), positionAfterLoad(0),
+    restoreFragmentAfterLoad(false), loaded(false), grabbingVolumeKeys(false)
 {
     TRACE;
+
+    // Set up web view defaults
     settings()->setAttribute(QWebSettings::AutoLoadImages, true);
     settings()->setAttribute(QWebSettings::JavascriptEnabled, true);
     settings()->setAttribute(QWebSettings::JavaEnabled, false);
@@ -40,49 +40,55 @@ BookView::BookView(QWidget *parent):
                              false);
     settings()->setDefaultTextEncoding("utf-8");
     page()->setContentEditable(false);
-
-#if defined(Q_WS_MAEMO_5) || defined(Q_OS_SYMBIAN)
-    // Suppress unwanted text selections on Maemo and Symbian
-    installEventFilter(this);
-#endif
     QWebFrame *frame = page()->mainFrame();
 #if defined(Q_WS_MAEMO_5) || defined(Q_OS_SYMBIAN)
     frame->setScrollBarPolicy(Qt::Vertical, Qt::ScrollBarAlwaysOff);
 #endif
     frame->setScrollBarPolicy(Qt::Horizontal, Qt::ScrollBarAlwaysOff);
-
-    bookmarkImage = QImage(":/icons/bookmark.png");
-
     connect(this, SIGNAL(loadFinished(bool)), this, SLOT(onLoadFinished(bool)));
     connect(frame, SIGNAL(javaScriptWindowObjectCleared()),
             this, SLOT(addJavaScriptObjects()));
-    connect(frame, SIGNAL(contentsSizeChanged(const QSize &)),
-            this, SLOT(onContentsSizeChanged(const QSize &)));
-    connect(Settings::instance(), SIGNAL(valueChanged(const QString &)),
-            this, SLOT(onSettingsChanged(const QString &)));
+
+    // Suppress unwanted text selections on Maemo and Symbian
+#if defined(Q_WS_MAEMO_5) || defined(Q_OS_SYMBIAN)
+    installEventFilter(this);
+#endif
+
+    // Pre-load bookmark icon
+    bookmarkImage = QImage(":/icons/bookmark.png");
+
+    // Handle settings changes, force handling initial settings
     Settings *s = Settings::instance();
+    connect(s, SIGNAL(valueChanged(const QString &)),
+            this, SLOT(onSettingsChanged(const QString &)));
     s->setValue("zoom", s->value("zoom", 160));
     s->setValue("font", s->value("font", Platform::defaultFont()));
     s->setValue("scheme", s->value("scheme", "default"));
+    s->setValue("usevolumekeys", s->value("usevolumekeys", false));
     setBook(0);
 
+    // Enable kinetic scrolling
 #if defined(Q_WS_MAEMO_5)
     scrollerMonitor = 0;
     scroller = property("kineticScroller").value<QAbstractKineticScroller *>();
 #elif defined(Q_OS_SYMBIAN)
-    FlickCharm *charm = new FlickCharm(this);
+    scrollerMonitor = 0;
+    charm = new FlickCharm(this);
     charm->activateOn(this);
 #endif
-}
 
-BookView::~BookView()
-{
-    TRACE;
+    // Observe media keys on Symbian
+#ifdef Q_OS_SYMBIAN
+    MediaKeysObserver *observer = MediaKeysObserver::instance();
+    connect(observer, SIGNAL(mediaKeyPressed(MediaKeysObserver::MediaKeys)),
+            this, SLOT(onMediaKeysPressed(MediaKeysObserver::MediaKeys)));
+#endif
 }
 
 void BookView::loadContent(int index)
 {
     TRACE;
+
     if (!mBook) {
         return;
     }
@@ -158,8 +164,9 @@ void BookView::setLastBookmark()
 {
     TRACE;
     if (mBook) {
-        int height = contentsHeight;
-        int pos = page()->mainFrame()->scrollPosition().y();
+        QWebFrame *frame = page()->mainFrame();
+        int height = frame->contentsSize().height();
+        int pos = frame->scrollPosition().y();
         qDebug() << QString("At %1 (%2%, height %3)").
                 arg(pos).arg((qreal)pos / (qreal)height * 100).arg(height);
         mBook->setLastBookmark(contentIndex, (qreal)pos / (qreal)height);
@@ -226,6 +233,25 @@ void BookView::onLoadFinished(bool ok)
     }
     loaded = true;
     onSettingsChanged("scheme");
+    onSettingsChanged("zoom");
+    onSettingsChanged("font");
+
+    QTimer::singleShot(210, this, SLOT(restoreAfterLoad()));
+}
+
+void BookView::restoreAfterLoad()
+{
+    TRACE;
+    if (restoreFragmentAfterLoad) {
+        qDebug() << "Restorint to fragment" << fragmentAfterLoad;
+        goToFragment(fragmentAfterLoad);
+        restoreFragmentAfterLoad = false;
+    } else if (restorePositionAfterLoad) {
+        qDebug() << "Restoring to position" << positionAfterLoad;
+        goToPosition(positionAfterLoad);
+        restorePositionAfterLoad = false;
+    }
+
     emit partLoadEnd(contentIndex);
     showProgress();
 }
@@ -255,6 +281,9 @@ void BookView::onSettingsChanged(const QString &key)
         script.close();
         QVariant ret = frame->evaluateJavaScript(scriptText);
     }
+    else if (key == "usevolumekeys") {
+        grabVolumeKeys(Settings::instance()->value(key).toBool());
+    }
 }
 
 void BookView::paintEvent(QPaintEvent *e)
@@ -265,7 +294,9 @@ void BookView::paintEvent(QPaintEvent *e)
     }
 
     // Paint bookmarks
-    QPoint scrollPos = page()->mainFrame()->scrollPosition();
+    QWebFrame *frame = page()->mainFrame();
+    int contentsHeight = frame->contentsSize().height();
+    QPoint scrollPos = frame->scrollPosition();
     QPixmap bookmarkPixmap = QPixmap::fromImage(bookmarkImage);
     QPainter painter(this);
     foreach (Book::Bookmark b, mBook->bookmarks()) {
@@ -281,7 +312,7 @@ void BookView::paintEvent(QPaintEvent *e)
 void BookView::mousePressEvent(QMouseEvent *e)
 {
     QWebView::mousePressEvent(e);
-#ifdef Q_WS_MAEMO_5
+#if defined(Q_WS_MAEMO_5)
     // Start monitoring kinetic scroll
     if (scrollerMonitor) {
         killTimer(scrollerMonitor);
@@ -327,6 +358,7 @@ QString BookView::tmpPath()
 
 bool BookView::eventFilter(QObject *o, QEvent *e)
 {
+#if 0
     if (e->type() != QEvent::Paint && e->type() != QEvent::MouseMove) {
         if (e->type() == QEvent::Resize) {
             qDebug() << "BookView::eventFilter QEvent::Resize to"
@@ -338,6 +370,7 @@ bool BookView::eventFilter(QObject *o, QEvent *e)
             qDebug() << "BookView::eventFilter" << Trace::event(e->type());
         }
     }
+#endif
 
     // Work around Qt bug that sometimes selects web view contents during swipe
     switch (e->type()) {
@@ -368,21 +401,6 @@ void BookView::addJavaScriptObjects()
     page()->mainFrame()->addToJavaScriptWindowObject("bv", this);
 }
 
-void BookView::onContentsSizeChanged(const QSize &size)
-{
-    TRACE;
-    contentsHeight = size.height();
-    if (restoreFragmentAfterLoad) {
-        qDebug() << "Restorint to fragment" << fragmentAfterLoad;
-        goToFragment(fragmentAfterLoad);
-    } else if (restorePositionAfterLoad) {
-        qDebug() << "Restoring to position";
-        goToPosition(positionAfterLoad);
-    }
-    restorePositionAfterLoad = false;
-    restoreFragmentAfterLoad = false;
-}
-
 #ifdef Q_WS_MAEMO_5
 
 void BookView::leaveEvent(QEvent *e)
@@ -406,6 +424,7 @@ void BookView::enterEvent(QEvent *e)
 
 void BookView::goToPosition(qreal position)
 {
+    int contentsHeight = page()->mainFrame()->contentsSize().height();
     int scrollPos = (int)((qreal)contentsHeight * position);
     page()->mainFrame()->setScrollPosition(QPoint(0, scrollPos));
     // FIXME: update();
@@ -416,6 +435,7 @@ void BookView::goToPosition(qreal position)
 void BookView::showProgress()
 {
     if (mBook) {
+        int contentsHeight = page()->mainFrame()->contentsSize().height();
         qreal pos = (qreal)(page()->mainFrame()->scrollPosition().y()) /
                     (qreal)contentsHeight;
         emit progress(mBook->getProgress(contentIndex, pos));
@@ -424,7 +444,7 @@ void BookView::showProgress()
 
 void BookView::timerEvent(QTimerEvent *e)
 {
-#ifdef Q_WS_MAEMO_5
+#if defined(Q_WS_MAEMO_5)
     if (e->timerId() == scrollerMonitor) {
         if (scroller &&
             ((scroller->state() == QAbstractKineticScroller::AutoScrolling) ||
@@ -432,29 +452,13 @@ void BookView::timerEvent(QTimerEvent *e)
             showProgress();
         } else {
             killTimer(scrollerMonitor);
+            scrollerMonitor = -1;
         }
     }
 #endif
     QWebView::timerEvent(e);
 }
 
-void BookView::keyPressEvent(QKeyEvent* event)
-{
-    switch (event->key()) {
-    case Qt::Key_F7:
-        goNextPage();
-        event->accept();
-        break;
-    case Qt::Key_F8:
-        goPreviousPage();
-        event->accept();
-        break;
-    default:
-        ;
-    }
-    QWebView::keyPressEvent(event);
-}
-
 void BookView::goPreviousPage()
 {
     QWebFrame *frame = page()->mainFrame();
@@ -484,3 +488,28 @@ void BookView::goNextPage()
         showProgress();
     }
 }
+
+void BookView::grabVolumeKeys(bool grab)
+{
+    TRACE;
+    grabbingVolumeKeys = grab;
+}
+
+#ifdef Q_OS_SYMBIAN
+
+void BookView::onMediaKeysPressed(MediaKeysObserver::MediaKeys key)
+{
+    TRACE;
+    qDebug() << "Key" << (int)key;
+    if (grabbingVolumeKeys) {
+        if (key == MediaKeysObserver::EVolIncKey) {
+            qDebug() << "Volume up";
+            goPreviousPage();
+        } else if (key == MediaKeysObserver::EVolDecKey){
+            qDebug() << "Volume down";
+            goNextPage();
+        }
+    }
+}
+
+#endif // Q_OS_SYMBIAN
