@@ -10,10 +10,15 @@
 
 #include "book.h"
 
+#ifdef Q_OS_SYMBIAN
+#   include "mediakeysobserver.h"
+#endif
+
 class QModelIndex;
 class Progress;
 class QAbstractKineticScroller;
 class ProgressDialog;
+class FlickCharm;
 
 /** Visual representation of a book. */
 class BookView: public QWebView
@@ -22,7 +27,6 @@ class BookView: public QWebView
 
 public:
     explicit BookView(QWidget *parent = 0);
-    virtual ~BookView();
     void setBook(Book *book);
     Book *book();
     void goToBookmark(const Book::Bookmark &bookmark);
@@ -32,8 +36,14 @@ public:
     void goToPart(int part, const QString &fragment);
     void goToFragment(const QString &fragment);
 
+    /** If grab is true, volume keys will generate act as page up/down. */
+    void grabVolumeKeys(bool grab);
+
 signals:
+    /** Part loading started. */
     void partLoadStart(int index);
+
+    /** Part loading finished. */
     void partLoadEnd(int index);
 
     /** Signal button press, when the real event has been suppressed. */
@@ -49,34 +59,41 @@ public slots:
     /** Go to previous part. */
     void goNext();
 
+    /** Actions to perform after URL loading finished. */
     void onLoadFinished(bool ok);
+
+    /** Handle settings changes. */
     void onSettingsChanged(const QString &key);
 
     /** Add QObjects to the main frame. */
     void addJavaScriptObjects();
 
-    /** Handle main frame contents size changes. */
-    void onContentsSizeChanged(const QSize &size);
-
     /** Go to previous page. */
     void goPreviousPage();
 
     /** Go to next page. */
     void goNextPage();
 
+    /** Restore saved position after URL loading finished. */
+    void restoreAfterLoad();
+
+protected slots:
+#ifdef Q_OS_SYMBIAN
+    /** Observe media keys. */
+    void onMediaKeysPressed(MediaKeysObserver::MediaKeys key);
+#endif
+
 protected:
     void paintEvent(QPaintEvent *e);
     void mousePressEvent(QMouseEvent *e);
     void wheelEvent(QWheelEvent *);
     bool eventFilter(QObject *o, QEvent *e);
+    void timerEvent(QTimerEvent *e);
 #ifdef Q_WS_MAEMO_5
     void leaveEvent(QEvent *e);
     void enterEvent(QEvent *e);
 #endif // Q_WS_MAEMO_5
-    void timerEvent(QTimerEvent *e);
-    void keyPressEvent(QKeyEvent *e);
 
-private:
     /** Load given part. */
     void loadContent(int index);
 
@@ -89,25 +106,27 @@ private:
     /** Show reading progress. */
     void showProgress();
 
-    int contentIndex;   /**< Current part in book. */
-    Book *mBook;        /**< Book to show. */
+    int contentIndex;       /**< Current part in book. */
+    Book *mBook;            /**< Book to show. */
     bool restorePositionAfterLoad;
-                        /**< If true, restore current position after load. */
-    qreal positionAfterLoad;
-                        /**< Position to be restored after load. */
+                            /**< If true, restore current position after load. */
+    qreal positionAfterLoad;/**< Position to be restored after load. */
     bool restoreFragmentAfterLoad;
-                        /**< If true, restore fragment location after load. */
+                            /**< If true, restore fragment location after load. */
     QString fragmentAfterLoad;
-                        /**< Fragment location to be restored after load. */
-    QImage bookmarkImage;
-                        /**< Bookmark icon pre-loaded. */
-    bool loaded;        /**< True if content has been loaded. */
-    bool mousePressed;
-    int contentsHeight; /**< Last know height of the frame. */
+                            /**< Fragment location to be restored after load. */
+    QImage bookmarkImage;   /**< Bookmark icon pre-loaded. */
+    bool loaded;            /**< True, if content has been loaded. */
+    bool mousePressed;      /**< Event filter's mouse button state. */
+    bool grabbingVolumeKeys;/**< True, if volume keys should be grabbed. */
 
+#if defined(Q_WS_MAEMO_5) || defined(Q_OS_SYMBIAN)
+    int scrollerMonitor;    /**< ID of timer monitoring kinetic scroll. */
+#endif
 #if defined(Q_WS_MAEMO_5)
-    int scrollerMonitor;
     QAbstractKineticScroller *scroller;
+#elif defined(Q_OS_SYMBIAN)
+    FlickCharm *charm;
 #endif
 };
 
