@@ -11,10 +11,11 @@ class ListView;
 class QPushButton;
 class QModelIndex;
 class QCloseEvent;
-class QProgressDialog;
+class ProgressDialog;
 class Book;
 class InfoWindow;
 class SortedLibrary;
+class SearchDialog;
 
 /** Manage library. */
 class LibraryDialog: public ListWindow
@@ -37,13 +38,17 @@ public slots:
     void onCurrentBookChanged();
     void onAddFromFolder(const QString &path);
     void onAddFromFolderDone(int added);
+    void onSearch();
+    void showSearchResults();
+
 private:
     QString createItemText(const Book *book);
     void setSelected(const QModelIndex &index);
     QModelIndex selected() const;
     ListView *list;
     SortedLibrary *sortedLibrary;
-    QProgressDialog *progress;
+    ProgressDialog *progress;
+    SearchDialog *searchDialog;
 };
 
 #endif // LIBRARYDIALOG_H
