@@ -8,6 +8,11 @@
 #include "bookdb.h"
 #include "search.h"
 #include "platform.h"
+#include "splash.h"
+
+#ifdef Q_OS_SYMBIAN
+#   include "mediakeysobserver.h"
+#endif
 
 static const char *DORIAN_VERSION =
 #include "pkg/version.txt"
@@ -23,21 +28,36 @@ static const QtMsgType DORIAN_DEFAULT_TRACE_LEVEL =
 
 int main(int argc, char *argv[])
 {
-    QApplication a(argc, argv);
     int ret;
 
+    // Set up application
+    QApplication a(argc, argv);
     a.setApplicationName("Dorian");
     a.setApplicationVersion(DORIAN_VERSION);
     a.setOrganizationDomain("pipacs.com");
     a.setOrganizationName("Pipacs");
 
-    Trace::level = (QtMsgType)Settings::instance()->
+    // Initialize tracing
+    Settings *settings = Settings::instance();
+    Trace::level = (QtMsgType)settings->
         value("tracelevel", (int)DORIAN_DEFAULT_TRACE_LEVEL).toInt();
+    Trace::setFileName(settings->value("tracefilename").toString());
     qInstallMsgHandler(Trace::messageHandler);
 
+#ifdef Q_OS_SYMBIAN
+    // Show splash screen
+    Splash *splash = new Splash();
+    splash->showFullScreen();
+    a.processEvents();
+#endif
+
+    // Create main window, run event loop
     {
         MainWindow w;
-        w.show();
+#ifdef Q_OS_SYMBIAN
+        splash->close();
+        splash->deleteLater();
+#endif
         ret = a.exec();
     }
 
@@ -46,6 +66,9 @@ int main(int argc, char *argv[])
     BookDb::close();
     Settings::close();
     Search::close();
+#ifdef Q_OS_SYMBIAN
+    MediaKeysObserver::close();
+#endif
 
     // Re-start application if event loop exit code was 1000
     if (ret == 1000) {
