@@ -3,6 +3,8 @@
 
 #include <QString>
 
+class QWidget;
+
 /** Platform abstractions. */
 class Platform
 {
@@ -13,6 +15,9 @@ public:
     static QString version();
     static QString downloadDir();
     static QString defaultFont();
+    static void information(const QString &label, QWidget *parent = 0);
+    static void showBusy(QWidget *w, bool isBusy);
+    static QString traceFileName();
 };
 
 #endif // PLATFORM_H
